#!/usr/bin/python3
# -*- coding: utf-8 -*-


"""
Light wrapper for VK's API
"""


import requests


host = "api.vk.me"
proxyHost = "v-api-proxy.xtrafrancyz.net"
apiVersion = "5.125"

userAgent = {'user-agent': 'VKAndroidApp/6.10.3-5896 (Unknown; SDK 28; armeabi-v7a; Android 9; ru; 1920x1080)'}


class VKLight:
    """VKLigth - Light wrapper for VK's API"""

    def __init__(self, param= dict()):
        """
        :param: Dictionary including  fields such as 'access_token' (required), 'v' and etc.

        For example: dict(access_token="your access_token", v='5.125', lang="en", host="api.vk.me")
        """
        super(VKLight, self).__init__()

        self.access_token = self.__v("access_token", param) or ""
        self.apiVersion = self.__v("v", param) or apiVersion
        self.lang = self.__v("lang", param) or "en"
        
        self.host = proxyHost if self.__v("proxy", param) else host
        self.host = param['host'] if self.__v("host", param) else self.host
        self.baseURL = f"https://{self.host}/method/"
        self.url_param = dict(lang=self.lang, v=self.apiVersion)

    def __call__(self, method:str, args=dict()):
        return self.call(method, args)

    def call(self, method:str, args=dict()) -> dict:
        """
        Calls VK API methods
        :param method: VK API method name.
        :param args: arguments of this method.
        """
        args['access_token'] = self.access_token

        try:
            resp = requests.post(
                f"{self.baseURL}{method}", 
                data=args,
                params=self.url_param, 
                headers=userAgent, 
                timeout=10
            ).json()

        except Exception as e:
            raise e

        if 'error' in resp:
            raise VKLightError(resp['error']['error_code'], resp['error']['error_msg'])

        return resp
    
    def execute(self, code:str=""):
        """
        Calls Execute method
        Learn More: https://vk.com/dev/execute
           
        param:code= VKScript code 
        """
        return self.call("execute", {"code": code})

    def __v(self, key, dict_data: dict):
        return dict_data[key] if key in dict_data else ""



class VKLightError(Exception):
    """ VKLight Exception for errros from VK API's """
    def __init__(self, error_code, message):
        """
        :param error_code: Code of Error
        :param message: Error message
        """
        self.message, self.error_code = message, error_code

    def __str__(self):
        return "VKLightError {}: {}".format(self.error_code, self.message)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vklight']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.24.0,<3.0.0']

setup_kwargs = {
    'name': 'vklight',
    'version': '1.3.6',
    'description': "VKLight - Light wrapper for VK's API",
    'long_description': '# VKLight\n Легкая обёртка для работы с VK API.\n\n# Установка\n```\npip install vklight\n```\n\n\n# Пример использования\n\n```python\nfrom vklight import VKLight, VKLightError\n\napi = VKLight({\n\t"access_token": "...",\n\t"v": "5.150",\n\t"lang": "ru",\n\t"host": "api.vk.me"\n})\n```\n```python\ntry:\n\tapi.call("users.get", { "user_id": 1})\nexcept VKLightError as e:\n\tprint(e) \n# {\'response\': [{\'id\': 1, \'first_name\': \'Павел\', \'last_name\': \'Дуров\', \'is_closed\': False, \'can_access_closed\': True}]}\n```\nили \n```python\napi("users.get", {"user_id": 1})\n# {\'response\': [{\'id\': 1, \'first_name\': \'Павел\', \'last_name\': \'Дуров\', \'is_closed\': False, \'can_access_closed\': True}]}\n```\n\nИспользование execute-методов\n```python\napi.execute(r"return API.users.get({\'user_id\': 1});")\n# {\'response\': [{\'id\': 1, \'first_name\': \'Павел\', \'last_name\': \'Дуров\', \'is_closed\': False, \'can_access_closed\': True}]}\n```\n\n# Лицензия\nMIT License',
    'author': 'Ivan',
    'author_email': 'pass@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
